==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.SkuArgs.builder
import com.pulumi.azurenative.databoxedge.kotlin.enums.SkuName
import com.pulumi.azurenative.databoxedge.kotlin.enums.SkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The SKU type.
 * @property name SKU name.
 * @property tier The SKU tier. This is based on the SKU name.
 */
public data class SkuArgs(
    public val name: Output<Either<String, SkuName>>? = null,
    public val tier: Output<Either<String, SkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.SkuArgs =
        com.pulumi.azurenative.databoxedge.inputs.SkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, SkuName>>? = null

    private var tier: Output<Either<String, SkuTier>>? = null

    /**
     * @param value SKU name.
     */
    @JvmName("gwdscvipvnakgfih")
    public suspend fun name(`value`: Output<Either<String, SkuName>>) {
        this.name = value
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("tatsopvmlompxbwx")
    public suspend fun tier(`value`: Output<Either<String, SkuTier>>) {
        this.tier = value
    }

    /**
     * @param value SKU name.
     */
    @JvmName("pohcvtfqqlmofpjl")
    public suspend fun name(`value`: Either<String, SkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name.
     */
    @JvmName("gtptwflldxqqyurk")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name.
     */
    @JvmName("agjoeqvidfwgoegy")
    public fun name(`value`: SkuName) {
        val toBeMapped = Either.ofRight<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("tuiaiubwkinxmgsd")
    public suspend fun tier(`value`: Either<String, SkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("cvcpsbpcafoeifyh")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("pkyaheqswinwnysr")
    public fun tier(`value`: SkuTier) {
        val toBeMapped = Either.ofRight<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name,
        tier = tier,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/SkuArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.SkuArgs.builder
import com.pulumi.azurenative.databoxedge.kotlin.enums.SkuName
import com.pulumi.azurenative.databoxedge.kotlin.enums.SkuTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The SKU type.
 * @property name SKU name.
 * @property tier The SKU tier. This is based on the SKU name.
 */
public data class SkuArgs(
    public val name: Output<Either<String, SkuName>>? = null,
    public val tier: Output<Either<String, SkuTier>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.SkuArgs> {
    override fun toJava(): com.pulumi.azurenative.databoxedge.inputs.SkuArgs =
        com.pulumi.azurenative.databoxedge.inputs.SkuArgs.builder()
            .name(
                name?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tier(
                tier?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [SkuArgs].
 */
@PulumiTagMarker
public class SkuArgsBuilder internal constructor() {
    private var name: Output<Either<String, SkuName>>? = null

    private var tier: Output<Either<String, SkuTier>>? = null

    /**
     * @param value SKU name.
     */
    @JvmName("mmwwbliywemmucsl")
    public suspend fun name(`value`: Output<Either<String, SkuName>>) {
        this.name = value
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("fkyiouqfseopouca")
    public suspend fun tier(`value`: Output<Either<String, SkuTier>>) {
        this.tier = value
    }

    /**
     * @param value SKU name.
     */
    @JvmName("tlhqagryqgvcursp")
    public suspend fun name(`value`: Either<String, SkuName>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name.
     */
    @JvmName("vrcungnuubnycrwu")
    public fun name(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value SKU name.
     */
    @JvmName("siaewjsmlhuttfhg")
    public fun name(`value`: SkuName) {
        val toBeMapped = Either.ofRight<String, SkuName>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("qaykmeuifrimqbnn")
    public suspend fun tier(`value`: Either<String, SkuTier>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("xoxgygcnntgclyvf")
    public fun tier(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    /**
     * @param value The SKU tier. This is based on the SKU name.
     */
    @JvmName("dqdqmftriygtxgja")
    public fun tier(`value`: SkuTier) {
        val toBeMapped = Either.ofRight<String, SkuTier>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tier = mapped
    }

    internal fun build(): SkuArgs = SkuArgs(
        name = name,
        tier = tier,
    )
}
